package agilpizza.modelo;

import java.util.ArrayList;
import java.util.List;

public class PizzaMontada extends Pizza {

	public PizzaMontada() {
		ingredientes = new ArrayList<Ingrediente>();
	}

	public void adicionaIngredientes(List<Ingrediente> ingredientes) {
		if (ingredientes != null)
		   this.ingredientes.addAll(ingredientes);
	}

	public void adicionaIngrediente(Ingrediente ingrediente) {
		ingredientes.add(ingrediente);
	}

	public void removeIngrediente(Ingrediente ingrediente) {
		ingredientes.remove(ingrediente);
	}

	public void removeIngredientes(List<Ingrediente> ingredientes) {
		this.ingredientes.removeAll(ingredientes);
	}

	@Override
	public String getDescricao() {
		if (ingredientes.isEmpty()) {
			return "Só massa";
		}
		return getDescricaoIngredientes();
	}
}
